==> config-api-0.3.11-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/HTTPConnector.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Used by a remote client to define how it connects to a server over HTTP.
 */
@ResourceType("http-connector")
public class HTTPConnector<T extends HTTPConnector> {

	private String key;
	private String endpoint;
	private Map params = new java.util.HashMap<String, Object>();
	private String socketBinding;

	public HTTPConnector(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The http-acceptor that serves as the endpoint of this http-connector.
	 */
	@ModelNodeBinding(detypedName = "endpoint")
	public String endpoint() {
		return this.endpoint;
	}

	/**
	 * The http-acceptor that serves as the endpoint of this http-connector.
	 */
	@SuppressWarnings("unchecked")
	public HTTPConnector endpoint(String value) {
		this.endpoint = value;
		return (HTTPConnector) this;
	}

	/**
	 * A key-value pair understood by the connector factory-class and used to configure it.
	 */
	@ModelNodeBinding(detypedName = "params")
	public Map params() {
		return this.params;
	}

	/**
	 * A key-value pair understood by the connector factory-class and used to configure it.
	 */
	@SuppressWarnings("unchecked")
	public HTTPConnector params(Map value) {
		this.params = value;
		return (HTTPConnector) this;
	}

	/**
	 * A key-value pair understood by the connector factory-class and used to configure it.
	 */
	public HTTPConnector paramsEntry(String key, Object value) {
		this.params.put(key, value);
		return (HTTPConnector) this;
	}

	/**
	 * The socket binding that the connector will use to create connections.
	 */
	@ModelNodeBinding(detypedName = "socket-binding")
	public String socketBinding() {
		return this.socketBinding;
	}

	/**
	 * The socket binding that the connector will use to create connections.
	 */
	@SuppressWarnings("unchecked")
	public HTTPConnector socketBinding(String value) {
		this.socketBinding = value;
		return (HTTPConnector) this;
	}
}

==> config-api-0.3.12-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/HTTPConnector.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * Used by a remote client to define how it connects to a server over HTTP.
 */
@ResourceType("http-connector")
public class HTTPConnector<T extends HTTPConnector> {

	private String key;
	private String endpoint;
	private Map params;
	private String socketBinding;

	public HTTPConnector(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The http-acceptor that serves as the endpoint of this http-connector.
	 */
	@ModelNodeBinding(detypedName = "endpoint")
	public String endpoint() {
		return this.endpoint;
	}

	/**
	 * The http-acceptor that serves as the endpoint of this http-connector.
	 */
	@SuppressWarnings("unchecked")
	public T endpoint(String value) {
		this.endpoint = value;
		return (T) this;
	}

	/**
	 * A key-value pair understood by the connector factory-class and used to configure it.
	 */
	@ModelNodeBinding(detypedName = "params")
	public Map params() {
		return this.params;
	}

	/**
	 * A key-value pair understood by the connector factory-class and used to configure it.
	 */
	@SuppressWarnings("unchecked")
	public T params(Map value) {
		this.params = value;
		return (T) this;
	}

	/**
	 * A key-value pair understood by the connector factory-class and used to configure it.
	 */
	public T param(String key, Object value) {
		if (this.params == null) {
			this.params = new java.util.HashMap<>();
		}
		this.params.put(key, value);
		return (T) this;
	}

	/**
	 * The socket binding that the connector will use to create connections.
	 */
	@ModelNodeBinding(detypedName = "socket-binding")
	public String socketBinding() {
		return this.socketBinding;
	}

	/**
	 * The socket binding that the connector will use to create connections.
	 */
	@SuppressWarnings("unchecked")
	public T socketBinding(String value) {
		this.socketBinding = value;
		return (T) this;
	}
}
